@@ -1,6 +1,7 @@
-__all__ = ["DiskCache", "Apply", "NTU", "UCLA"]
+__all__ = ["DiskCache", "Apply", "NTU", "UCLA", "BABEL"]
 
 from .base_dataset import DiskCache, Apply
 
 from .ntu import NTU
 from .ucla import UCLA
+from .babel import BABEL
